==> v0.4.0.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/search/Scroll.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search;

import org.elasticsearch.util.TimeValue;
import org.elasticsearch.util.io.Streamable;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import static org.elasticsearch.util.TimeValue.*;

/**
 * @author kimchy (Shay Banon)
 */
public class Scroll implements Streamable {

    private TimeValue timeout;

    private Scroll() {

    }

    public Scroll(TimeValue timeout) {
        this.timeout = timeout;
    }

    public TimeValue timeout() {
        return timeout;
    }

    public static Scroll readScroll(DataInput in) throws IOException, ClassNotFoundException {
        Scroll scroll = new Scroll();
        scroll.readFrom(in);
        return scroll;
    }

    @Override public void readFrom(DataInput in) throws IOException, ClassNotFoundException {
        timeout = readTimeValue(in);
    }

    @Override public void writeTo(DataOutput out) throws IOException {
        timeout.writeTo(out);
    }
}

==> v0.5.1.tar.gz: elasticsearch/modules/elasticsearch/src/main/java/org/elasticsearch/search/Scroll.java <==
/*
 * Licensed to Elastic Search and Shay Banon under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. Elastic Search licenses this
 * file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.search;

import org.elasticsearch.util.TimeValue;
import org.elasticsearch.util.io.Streamable;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;

import static org.elasticsearch.util.TimeValue.*;

/**
 * A scroll enables scrolling of search request. It holds a {@link #keepAlive()} time that
 * will control how long to keep the scrolling resources open.
 *
 * @author kimchy (shay.banon)
 */
public class Scroll implements Streamable {

    private TimeValue keepAlive;

    private Scroll() {

    }

    /**
     * Constructs a new scroll of the provided keep alive.
     */
    public Scroll(TimeValue keepAlive) {
        this.keepAlive = keepAlive;
    }

    /**
     * How long the resources will be kept open to support the scroll request.
     */
    public TimeValue keepAlive() {
        return keepAlive;
    }

    public static Scroll readScroll(DataInput in) throws IOException, ClassNotFoundException {
        Scroll scroll = new Scroll();
        scroll.readFrom(in);
        return scroll;
    }

    @Override public void readFrom(DataInput in) throws IOException, ClassNotFoundException {
        if (in.readBoolean()) {
            keepAlive = readTimeValue(in);
        }
    }

    @Override public void writeTo(DataOutput out) throws IOException {
        if (keepAlive == null) {
            out.writeBoolean(false);
        } else {
            out.writeBoolean(true);
            keepAlive.writeTo(out);
        }
    }
}
